{-# LANGUAGE NoImplicitPrelude #-}
module Stack.Build.ExecuteSpec (main, spec) where

import Stack.Prelude
import Test.Hspec

main :: IO ()
main = hspec spec

spec :: Spec
spec = return ()
